/*global module:false*/
module.exports = function(grunt) {

  // Project configuration.
  grunt.initConfig({
    pkg: '<json:package.json>',
    meta: {
      banner: '/*! <%= pkg.title || pkg.name %> - v<%= pkg.version %> - ' +
        '<%= grunt.template.today("yyyy-mm-dd") %>\n' +
        '<%= pkg.homepage ? "* " + pkg.homepage + "\n" : "" %>' +
        '* Copyright (c) <%= grunt.template.today("yyyy") %> <%= pkg.author.name %>;' +
        ' Licensed <%= _.pluck(pkg.licenses, "type").join(", ") %> */'
    },
    concat: {
      dist: {
        src: ['<banner:meta.banner>', '<file_strip_banner:src/<%= pkg.name %>.js>'],
        dest: 'dist/<%= pkg.name %>.js'
      }
    },
    min: {
      dist: {
        src: ['<banner:meta.banner>', '<config:concat.dist.dest>'],
        dest: 'dist/<%= pkg.name %>.min.js'
      }
    },
    qunit: {
      files: ['test/**/*.html']
    },
    lint: {
      files: ['grunt.js', 'src/**/*.js', 'test/**/*.js']
    },
    watch: {
      files: '<config:lint.files>',
      tasks: 'lint qunit'
    },
    jshint: {
      options: {
        curly: true,
        eqeqeq: true,
        immed: true,
        latedef: true,
        newcap: true,
        noarg: true,
        sub: true,
        undef: true,
        boss: true,
        eqnull: true,
        browser: true
      },
      globals: {
        jQuery: true
      }
    },
    uglify: {}
  });

  // Default task.
  grunt.registerTask('default', 'lint qunit manifest concat min');

  grunt.registerTask( "manifest", function() {
    var pkg = grunt.config( "pkg" );
    grunt.file.write( "requestAnimationFrame.jquery.json", JSON.stringify({
      name: "requestAnimationFrame",
      title: pkg.title,
      description: pkg.description,
      keywords: pkg.keywords,
      version: pkg.version,
      author: pkg.author,
      maintainers: pkg.maintainers,
      licenses: pkg.licenses.map(function( license ) {
        license.url = license.url.replace( "master", pkg.version );
        return license;
      }),
      bugs: pkg.bugs,
      homepage: pkg.homepage,
      docs: pkg.homepage,
      dependencies: {
        jquery: ">=1.8"
      }
    }, null, "\t" ) );
  });

};
